@@ -70,9 +70,9 @@ class MomoPayProcessor:
     def setMerchant(self):
 
         if self.merchant is not None:
-            self.merchantID = merchant.get('id')
-            self.merchant_username = merchant.get('username')
-            self.merchant_password = merchant.get('password')
+            self.merchantID = self.merchant.get('id')
+            self.merchant_username = self.merchant.get('username')
+            self.merchant_password = self.merchant.get('password')
         else:
             try:
                 self.merchantID = settings.PAYMENT_MERCHANT
